==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/Stacked100AreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedAreaSeriesDescriptionMetadata } from "./StackedAreaSeriesDescriptionMetadata";
import { Stacked100AreaSeriesDescription } from "./Stacked100AreaSeriesDescription";
/**
 * @hidden
 */
export let Stacked100AreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class Stacked100AreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (Stacked100AreaSeriesDescriptionMetadata.a == null) {
                Stacked100AreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                Stacked100AreaSeriesDescriptionMetadata.c(Stacked100AreaSeriesDescriptionMetadata.a);
            }
            if (a.j(Stacked100AreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.y(Stacked100AreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            StackedAreaSeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            Stacked100AreaSeriesDescriptionMetadata.b(a);
            a.aa("Stacked100AreaSeries", () => new Stacked100AreaSeriesDescription());
            a.z("Stacked100AreaSeries", Stacked100AreaSeriesDescriptionMetadata.a);
        }
    }
    Stacked100AreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(Stacked100AreaSeriesDescriptionMetadata, 'Stacked100AreaSeriesDescriptionMetadata');
    Stacked100AreaSeriesDescriptionMetadata.a = null;
    return Stacked100AreaSeriesDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/Stacked100AreaSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedAreaSeriesDescriptionMetadata } from "./StackedAreaSeriesDescriptionMetadata";
import { Stacked100AreaSeriesDescription } from "./Stacked100AreaSeriesDescription";
/**
 * @hidden
 */
export let Stacked100AreaSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class Stacked100AreaSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (Stacked100AreaSeriesDescriptionMetadata.a == null) {
                Stacked100AreaSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                Stacked100AreaSeriesDescriptionMetadata.c(Stacked100AreaSeriesDescriptionMetadata.a);
            }
            if (a.k(Stacked100AreaSeriesDescriptionMetadata.a)) {
                return;
            }
            a.aa(Stacked100AreaSeriesDescriptionMetadata.a);
        }
        static c(a) {
            StackedAreaSeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            Stacked100AreaSeriesDescriptionMetadata.b(a);
            a.ac("Stacked100AreaSeries", () => new Stacked100AreaSeriesDescription());
            a.ab("Stacked100AreaSeries", Stacked100AreaSeriesDescriptionMetadata.a);
        }
    }
    Stacked100AreaSeriesDescriptionMetadata.$t = /*@__PURE__*/ markType(Stacked100AreaSeriesDescriptionMetadata, 'Stacked100AreaSeriesDescriptionMetadata');
    Stacked100AreaSeriesDescriptionMetadata.a = null;
    return Stacked100AreaSeriesDescriptionMetadata;
})();
